==> igniteui-react-charts-16.4.1.tgz: package/ES2015/ColumnSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { ConsolidatedItemsPosition_$type } from "./ConsolidatedItemsPosition";
import { Type, runOn, enumGetBox, markType, fromEnum } from "igniteui-react-core/ES2015/type";
import { Pool$1 } from "igniteui-react-core/ES2015/Pool$1";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { ScalerParams } from "./ScalerParams";
import { Rectangle } from "igniteui-react-core/ES2015/Rectangle";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { isNaN_, isInfinity } from "igniteui-react-core/ES2015/number";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
export class ColumnSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.qd = null;
        this.p8 = 0;
        this.ab = ColumnSeries.$;
        this.pr = 2;
    }
    bf() {
        return new ColumnSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.p7 = a;
    }
    m7() {
        return 1;
    }
    get_nm() {
        return true;
    }
    get nm() {
        return this.get_nm();
    }
    preferredCategoryMode(a) {
        return this.pr;
    }
    ll(a) {
        if (this.qd == null) {
            this.qd = runOn(this, this.qa);
        }
        let b = this.pu != null ? this.pu : this.yAxis;
        let c = this.po;
        return this.ot.c$d(this, a, c, b, this.my, this.ny(this.bi), this.nz(this.bi), this.qd);
    }
    df(a, b) {
        if (this.di(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        if (a && c.c5 != null) {
            c.c5.count = 0;
        }
    }
    ec() {
        return this.po.jk(this.bi.bq, this.bi.bp, this.getEffectiveViewport1(this.bi));
    }
    oe(a, b) {
        super.oe(a, b);
        let c = a.f;
        if (!b.q()) {
            return;
        }
        let d = b.bq;
        let e = b.bp;
        let f = this.getEffectiveViewport1(b);
        let g = new ScalerParams(0, d, e, this.pu.b8, f);
        g.b = this.ed();
        let h = new ScalerParams(0, d, e, this.po.b8, f);
        let i = this.pu;
        let j = i.dt(i.j7, g);
        let k = this.po.jk(d, e, f);
        let l = this.po;
        let m = b;
        if (isNaN_(k) || isInfinity(k)) {
            m.c5.count = 0;
            return;
        }
        this.m5.x(this, this.nq(), this.po, runOn(this, this.mr), this.ny(b), this.nz(b));
        this.m5.p = this.qb;
        this.m5.q = this.qc;
        this.m5.j = this.qb;
        this.m5.k = this.qc;
        let n = false;
        let o = this.m5.c;
        if (o != null) {
            n = true;
        }
        let p = this.po.cc;
        let q = p ? this.po : null;
        let r = this.valueColumn.count;
        let s = this.ny(b);
        let t = 0;
        for (let u = 0; u < c.count; ++u) {
            let v = c._inner[u][0] - 0.5 * k;
            let w = this.qa(c._inner[u]);
            let x = j;
            w = Math.max(w, -100);
            x = Math.min(x, e.bottom + 100);
            let y = Math.abs(x - w);
            if (isInfinity(y)) {
                continue;
            }
            let z = m.c5.item(t);
            t++;
            z.width = k;
            z.height = y;
            if (n) {
                this.oa(c, u, r, l, h, b.n);
            }
            if (z.dataContext != null) {
                let aa = z.dataContext;
                if (s == 1) {
                    let ab = this.m5.a(r, u)[0];
                    if (ab >= 0 && ab < this.bz.count) {
                        if (q != null && q.i$b != null && q.i$b.count > ab) {
                            ab = q.i$b._inner[ab];
                        }
                        aa.item = this.bz.item(ab);
                    }
                }
                else {
                    aa.item = null;
                }
            }
            this.m5.ae(z, false, false, false, false);
            z.al = this.m5.j;
            z.am = this.m5.k;
            m.da(z, v, Math.min(x, w));
        }
        m.c5.count = t;
        b.cs(a);
    }
    get p9() {
        return this.p8;
    }
    set p9(a) {
        if (this.p9 != a) {
            let b = this.p9;
            this.p8 = a;
            this.raisePropertyChanged("ConsolidatedColumnVerticalPosition", enumGetBox(ConsolidatedItemsPosition_$type, b), enumGetBox(ConsolidatedItemsPosition_$type, this.p9));
        }
    }
    qa(a) {
        if (a == null || a.length < 3) {
            return NaN;
        }
        switch (this.p9) {
            case 0: return a[1];
            case 1: return a[2];
            case 2: return (a[1] + a[2]) / 2;
            case 3:
                let b = (a[1] + a[2]) / 2;
                if (this.yAxis == null) {
                    return b;
                }
                let c = this.yAxis.dw(b, new ScalerParams(1, this.bs.mz, this.bs.my, this.yAxis.b8));
                if (c < this.yAxis.j7) {
                    return a[2];
                }
                else {
                    return a[1];
                }
            case 4:
                let d = (a[1] + a[2]) / 2;
                let e = this.yAxis.dw(d, new ScalerParams(1, this.bs.mz, this.bs.my, this.yAxis.b8));
                if (this.yAxis == null) {
                    return d;
                }
                if (e < this.yAxis.j7) {
                    return a[1];
                }
                else {
                    return a[2];
                }
            default: return (a[1] + a[2]) / 2;
        }
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
ColumnSeries.$t = markType(ColumnSeries, 'ColumnSeries', HorizontalAnchoredCategorySeries.$);
Type.dep(DependencyProperty, PropertyMetadata, ColumnSeries, 'raisePropertyChanged', ['RadiusX:qb:qh', [1, 2], 'RadiusY:qc:qi', [1, 2]]);
export class ColumnSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c4 = null;
        this.c6 = null;
        this.db = new Rectangle();
        this.c5 = null;
        this.c4 = a;
        this.c5 = ((() => {
            let $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(this, this.dc);
            $ret.activate = runOn(this, this.c7);
            $ret.disactivate = runOn(this, this.c9);
            $ret.destroy = runOn(this, this.c8);
            return $ret;
        })());
    }
    ap() {
        super.ap();
        this.c6 = new List$1(Rectangle.$, 0);
        if (!this.n) {
            this.e.eq = 4;
            this.e.bj = 1;
        }
    }
    dc() {
        let a = new Rectangle();
        this.c6.add(a);
        a._visibility = 1;
        return a;
    }
    c7(a) {
        a._visibility = 0;
    }
    c9(a) {
        a._visibility = 1;
    }
    c8(a) {
        this.c6.remove(a);
    }
    da(a, b, c) {
        if (!this.isDirty) {
            this.an();
        }
        a.o = c;
        a.n = b;
    }
    z(a) {
        return this.c6._inner[a];
    }
    y(a) {
        let b = this.c6._inner[a];
        this.db._visibility = b._visibility;
        this.db.n = b.n;
        this.db.o = b.o;
        this.db.width = b.width;
        this.db.height = b.height;
        let c = this.bl(a);
        this.db._fill = c;
        this.db._stroke = c;
        this.db.ac = this.e.eu + 3;
        return this.db;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            for (let c = 0; c < this.c6.count; c++) {
                let d = this.x(c, b);
                this.ba(d, c, b);
                a.v(d);
            }
        }
    }
    ai(a) {
        super.ai(a);
        let b = 0;
        let c = new List$1(Rectangle.$, 0);
        for (let d of fromEnum(this.c5.a)) {
            c.add(d);
        }
        c.aa((e, f) => {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        for (let e of fromEnum(c)) {
            this.e.a2.exportRectangleData(a, e, "column" + b, ["Main", "Fill"]);
        }
        b++;
    }
}
ColumnSeriesView.$t = markType(ColumnSeriesView, 'ColumnSeriesView', AnchoredCategorySeriesView.$);
/*<BeginStatics Name="Infragistics.Controls.Charts.ColumnSeries" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.ColumnSeries" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES2015/ColumnSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { ConsolidatedItemsPosition_$type } from "./ConsolidatedItemsPosition";
import { Type, runOn, enumGetBox, markType, fromEnum } from "igniteui-react-core/ES2015/type";
import { Pool$1 } from "igniteui-react-core/ES2015/Pool$1";
import { Rectangle } from "igniteui-react-core/ES2015/Rectangle";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { isNaN_, isInfinity } from "igniteui-react-core/ES2015/number";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
export class ColumnSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.qe = null;
        this.p9 = 0;
        this.ab = ColumnSeries.$;
        this.ps = 2;
    }
    bf() {
        return new ColumnSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.p8 = a;
    }
    m7() {
        return 1;
    }
    get_nm() {
        return true;
    }
    preferredCategoryMode(a) {
        return this.ps;
    }
    ll(a) {
        if (this.qe == null) {
            this.qe = runOn(this, this.qb);
        }
        let b = this.pv != null ? this.pv : this.yAxis;
        let c = this.pp;
        return this.ou.c$d(this, a, c, b, this.my, this.ny(this.bi), this.nz(this.bi), this.qe);
    }
    df(a, b) {
        if (this.di(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        if (a && c.c7 != null) {
            c.c7.count = 0;
        }
    }
    ec() {
        return this.pp.jk(this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi));
    }
    of(a, b) {
        super.of(a, b);
        let c = a.f;
        if (!b.q()) {
            return;
        }
        let d = b.bs;
        let e = b.br;
        let f = this.getEffectiveViewport1(b);
        let g = new ScalerParams(0, d, e, this.pv.b8, f);
        g.b = this.ed();
        let h = new ScalerParams(0, d, e, this.pp.b8, f);
        let i = this.pv;
        let j = i.dt(i.j7, g);
        let k = this.pp.jk(d, e, f);
        let l = this.pp;
        let m = b;
        if (isNaN_(k) || isInfinity(k)) {
            m.c7.count = 0;
            return;
        }
        this.m5.x(this, this.nq(), this.pp, runOn(this, this.mr), this.ny(b), this.nz(b));
        this.m5.p = this.qc;
        this.m5.q = this.qd;
        this.m5.j = this.qc;
        this.m5.k = this.qd;
        let n = false;
        let o = this.m5.c;
        if (o != null) {
            n = true;
        }
        let p = this.pp.cc;
        let q = p ? this.pp : null;
        let r = this.valueColumn.count;
        let s = this.ny(b);
        let t = 0;
        for (let u = 0; u < c.count; ++u) {
            let v = c._inner[u][0] - 0.5 * k;
            let w = this.qb(c._inner[u]);
            let x = j;
            w = Math.max(w, -100);
            x = Math.min(x, e.bottom + 100);
            let y = Math.abs(x - w);
            if (isInfinity(y)) {
                continue;
            }
            let z = m.c7.item(t);
            t++;
            z.width = k;
            z.height = y;
            if (n) {
                this.ob(c, u, r, l, h, b.n);
            }
            if (z.dataContext != null) {
                let aa = z.dataContext;
                if (s == 1) {
                    let ab = this.m5.a(r, u)[0];
                    if (ab >= 0 && ab < this.bz.count) {
                        if (q != null && q.i$b != null && q.i$b.count > ab) {
                            ab = q.i$b._inner[ab];
                        }
                        aa.item = this.bz.item(ab);
                    }
                }
                else {
                    aa.item = null;
                }
            }
            this.m5.ae(z, false, false, false, false);
            z.al = this.m5.j;
            z.am = this.m5.k;
            m.dc(z, v, Math.min(x, w));
        }
        m.c7.count = t;
        b.cu(a);
    }
    get qa() {
        return this.p9;
    }
    set qa(a) {
        if (this.qa != a) {
            let b = this.qa;
            this.p9 = a;
            this.raisePropertyChanged("ConsolidatedColumnVerticalPosition", enumGetBox(ConsolidatedItemsPosition_$type, b), enumGetBox(ConsolidatedItemsPosition_$type, this.qa));
        }
    }
    qb(a) {
        if (a == null || a.length < 3) {
            return NaN;
        }
        switch (this.qa) {
            case 0: return a[1];
            case 1: return a[2];
            case 2: return (a[1] + a[2]) / 2;
            case 3:
                let b = (a[1] + a[2]) / 2;
                if (this.yAxis == null) {
                    return b;
                }
                let c = this.yAxis.dw(b, new ScalerParams(1, this.bs.m1, this.bs.m0, this.yAxis.b8));
                if (c < this.yAxis.j7) {
                    return a[2];
                }
                else {
                    return a[1];
                }
            case 4:
                let d = (a[1] + a[2]) / 2;
                let e = this.yAxis.dw(d, new ScalerParams(1, this.bs.m1, this.bs.m0, this.yAxis.b8));
                if (this.yAxis == null) {
                    return d;
                }
                if (e < this.yAxis.j7) {
                    return a[1];
                }
                else {
                    return a[2];
                }
            default: return (a[1] + a[2]) / 2;
        }
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
ColumnSeries.$t = markType(ColumnSeries, 'ColumnSeries', HorizontalAnchoredCategorySeries.$);
Type.dep(DependencyProperty, PropertyMetadata, ColumnSeries, 'raisePropertyChanged', ['RadiusX:qc:qi', [1, 2], 'RadiusY:qd:qj', [1, 2]]);
export class ColumnSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c6 = null;
        this.c8 = null;
        this.dd = new Rectangle();
        this.c7 = null;
        this.c6 = a;
        this.c7 = ((() => {
            let $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(this, this.de);
            $ret.activate = runOn(this, this.c9);
            $ret.disactivate = runOn(this, this.db);
            $ret.destroy = runOn(this, this.da);
            return $ret;
        })());
    }
    ap() {
        super.ap();
        this.c8 = new List$1(Rectangle.$, 0);
        if (!this.n) {
            this.e.eq = 4;
            this.e.bj = 1;
        }
    }
    de() {
        let a = new Rectangle();
        this.c8.add(a);
        a._visibility = 1;
        return a;
    }
    c9(a) {
        a._visibility = 0;
    }
    db(a) {
        a._visibility = 1;
    }
    da(a) {
        this.c8.remove(a);
    }
    dc(a, b, c) {
        if (!this.isDirty) {
            this.an();
        }
        a.o = c;
        a.n = b;
    }
    z(a) {
        return this.c8._inner[a];
    }
    y(a) {
        let b = this.c8._inner[a];
        this.dd._visibility = b._visibility;
        this.dd.n = b.n;
        this.dd.o = b.o;
        this.dd.width = b.width;
        this.dd.height = b.height;
        let c = this.bm(a);
        this.dd._fill = c;
        this.dd._stroke = c;
        this.dd.ac = this.e.eu + 3;
        return this.dd;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            for (let c = 0; c < this.c8.count; c++) {
                let d = this.x(c, b);
                this.ba(d, c, b);
                a.v(d);
            }
        }
    }
    ai(a) {
        super.ai(a);
        let b = 0;
        let c = new List$1(Rectangle.$, 0);
        for (let d of fromEnum(this.c7.a)) {
            c.add(d);
        }
        c.aa((e, f) => {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        for (let e of fromEnum(c)) {
            this.e.a2.exportRectangleData(a, e, "column" + b, ["Main", "Fill"]);
        }
        b++;
    }
}
ColumnSeriesView.$t = markType(ColumnSeriesView, 'ColumnSeriesView', AnchoredCategorySeriesView.$);
